@@ -13,6 +13,7 @@ Usage::
 """
 from typing import IO, Any, Dict, Type, Union
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
@@ -30,14 +31,15 @@ class Exceptions:
 
 class SageMakerRuntimeClient:
     """
-    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [SageMakerRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -48,7 +50,7 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
         """
 
     def invoke_endpoint(
@@ -62,5 +64,5 @@ class SageMakerRuntimeClient:
         TargetVariant: str = None,
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.50/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Client.invoke_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
         """
